@@ -3,7 +3,11 @@ use strict;
 use warnings;
 package Getopt::Lucid::Exception;
 # ABSTRACT: Exception classes for Getopt::Lucid
-our $VERSION = '1.00'; # VERSION
+our $VERSION = '1.02'; # VERSION
+
+use Exporter;
+our @ISA = qw/Exporter Exception::Class::Base/;
+our @EXPORT = qw( throw_spec throw_argv throw_usage);
 
 use Exception::Class 1.23 (
     "Getopt::Lucid::Exception" => {
@@ -12,34 +16,34 @@ use Exception::Class 1.23 (
 
     "Getopt::Lucid::Exception::Spec" => {
         description => "Invalid specification",
-        alias => "throw_spec"
     },
 
     "Getopt::Lucid::Exception::ARGV" => {
         description => "Invalid argument on command line",
-        alias => "throw_argv"
     },
 
     "Getopt::Lucid::Exception::Usage" => {
         description => "Invalid usage",
-        alias => "throw_usage"
     },
 
 );
 
-sub import {
-    my $caller = caller(0);
-    {
-        no strict 'refs';
-        *{$caller."::$_"} = *{__PACKAGE__."::$_"}
-            for qw( throw_spec throw_argv throw_usage);
-    }
+sub throw_spec {
+    Getopt::Lucid::Exception::Spec->throw("$_[0]\n");
+}
+
+sub throw_argv {
+    Getopt::Lucid::Exception::ARGV->throw("$_[0]\n");
+}
+
+sub throw_usage {
+    Getopt::Lucid::Exception::Usage->throw("$_[0]\n");
 }
 
 1;
 
-
 __END__
+
 =pod
 
 =head1 NAME
@@ -48,19 +52,27 @@ Getopt::Lucid::Exception - Exception classes for Getopt::Lucid
 
 =head1 VERSION
 
-version 1.00
+version 1.02
+
+=for Pod::Coverage description
+throw_argv
+throw_spec
+throw_usage
 
 =head1 AUTHOR
 
 David Golden <dagolden@cpan.org>
 
+=head1 CONTRIBUTOR
+
+Robert Bohne <rbo@cpan.org>
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2011 by David Golden.
+This software is Copyright (c) 2013 by David Golden.
 
 This is free software, licensed under:
 
   The Apache License, Version 2.0, January 2004
 
 =cut
-
